%define name		apache-mod_ssl
%define aname		apache
%define pname		httpd
%define cachedir        %{_var}/cache/%{pname}
%define logdir          %{_var}/log/%{pname}
%define confdir         %{_sysconfdir}/%{pname}/conf
%define contentdir 	/home/%{pname}
%define rundir          %{_var}/run

Summary: 	Apache HTTP daemon with SSL
Name: 		apache-mod_ssl
%define 	apversion 1.3.26
%define 	modversion 2.8.10
%define 	mmversion 1.2.1
Version: 	%{apversion}.%{modversion}
Release: 	1
License:    	Apache Software License
Vendor:     	Apache Software Foundation
Group:      	System Environment/Daemons
Source0: 	http://httpd.apache.org/dist/apache_%{apversion}.tar.gz
Source1: 	http://www.modssl.org/source/mod_ssl-%{modversion}-%{apversion}.tar.gz
Source2: 	http://www.engelschall.com/sw/mm/mm-%{mmversion}.tar.gz
Source3: 	httpd.init
Source4: 	httpd.log
Source5: 	README.RPM
Obsoletes: 	apache-suexec apache-extra apache-doc
Provides: 	webserver apache apache-mod_ssl
BuildRoot: 	/var/tmp/apache-root
Requires: 	initscripts >= 3.25
Requires: 	openssl >= 0.9.6
Prereq: 	/sbin/chkconfig
URL: 		http://www.modssl.org/
Packager:	Henri Gomez <hgomez@users.sourceforge.net>, Magnus Stenman <stone@hkust.se>


%description
apache-mod_ssl is Apache with SSL support
via mod_ssl and OpenSSL

Built with loadable modules (all standard modules enabled).
The configuration files provided with apache
and apache-mod_ssl are unchanged.


%package devel
Group: Development/Libraries
Summary: Module development tools for apache-mod_ssl.
Obsoletes: secureweb-devel
Provides: apache-devel


%description devel
The apache-devel package contains header files and the
apxs script needed to build Dynamic Shared Objects (DSOs) for Apache.

If you are installing apache-mod_ssl, and want to be able
to compile or develop additional modules, you'll have to
install this package.


%package manual
Group: Documentation
Summary: Documentation for the Apache Web server.

%description manual
The apache-manual package contains the complete manual and reference
guide for the Apache Web server.  If you need Apache documentation
installed on the local machine, install this package.  The information
can also be found on the Web at http://www.apache.org/docs/.


%prep 
rm -rf apache-mod_ssl_%{version}
mkdir -p apache-mod_ssl_%{version}
%setup -T -D -a 0 -n apache-mod_ssl_%{version}
%setup -T -D -a 1 -n apache-mod_ssl_%{version}
%setup -T -D -a 2 -n apache-mod_ssl_%{version}

%build
cd mm-%{mmversion}

OPTIM="$RPM_OPT_FLAGS" ./configure \
	--disable-shared 
make

cat >> ../apache_%{apversion}/config.layout <<EOF
#   Red Hat Linux 6.x layout
<Layout RedHat6>
    prefix:        %{_prefix}
    exec_prefix:   %{_prefix}
    bindir:        %{_bindir}
    sbindir:       %{_sbindir}
    libexecdir:    %{_libdir}/%{aname}
    mandir:        %{_mandir}
    sysconfdir:    %{confdir}
    datadir:       %{contentdir}
    iconsdir:      %{contentdir}/icons
    htdocsdir:     %{contentdir}/html
    manualdir:     %{contentdir}/manual
    cgidir:        %{contentdir}/cgi-bin
    includedir:    %{_includedir}/%{aname}
    localstatedir: %{_localstatedir}
    runtimedir:    %{rundir}
    logfiledir:    %{logdir}
    proxycachedir: %{cachedir}
</Layout>
EOF

cd ../mod_ssl-%{modversion}-%{apversion}

OPTIM="$RPM_OPT_FLAGS" ./configure \
	--with-perl=%{_bindir}/perl \
	--with-apache=../apache_%{apversion} \
	--with-ssl=SYSTEM \
	--with-mm=../mm-%{mmversion} \
	--with-layout=RedHat6 \
	--disable-rule=WANTHSREGEX \
	--enable-module=all \
	--enable-module=define \
	--enable-shared=max \
	--enable-suexec --suexec-caller=nobody \
	--suexec-uidmin=500 --suexec-gidmin=500 --suexec-umask=022

cd ../apache_%{apversion}
make
make certificate TYPE=dummy
cd ..


%install
rm -rf ${RPM_BUILD_ROOT}
cd apache_%{apversion}
make install-quiet root="${RPM_BUILD_ROOT}" \
	conf_group="nobody" \
	conf_port="80" \
	conf_port_ssl="443" \
	conf_serveradmin="webmaster@localhost" \
	conf_servername="localhost"

strip ${RPM_BUILD_ROOT}/%{_sbindir}/%{pname}
strip ${RPM_BUILD_ROOT}/%{_libdir}/%{aname}/*.so

# rename directory name of contributed code
mv ../mod_ssl-%{modversion}-%{apversion}/pkg.contrib \
   ../mod_ssl-%{modversion}-%{apversion}/contrib

# the search script is not used
rm -r ${RPM_BUILD_ROOT}/%{contentdir}/manual/search/

# sysv init and logging
mkdir -p ${RPM_BUILD_ROOT}/etc/logrotate.d
mkdir -p ${RPM_BUILD_ROOT}/%{_initrddir}
install $RPM_SOURCE_DIR/httpd.log ${RPM_BUILD_ROOT}/%{_sysconfdir}/logrotate.d/%{pname}
install $RPM_SOURCE_DIR/httpd.init ${RPM_BUILD_ROOT}/%{_initrddir}/%{pname}

# replace Define SSL by Define HAVE_SSL
perl -pi -e 's/<IfDefine SSL>/<IfDefine HAVE_SSL>/g' ${RPM_BUILD_ROOT}/%{confdir}/%{pname}.conf


%clean
rm -rf "${RPM_BUILD_ROOT}"


%post
/sbin/chkconfig --add httpd
echo ""
echo ""
echo "As supplied httpd -DHAVE_SSL will run with a dummy certificate!!"
echo ""
echo "You need a server.key file in /etc/httpd/conf/ssl.key/"
echo "and you need a server.crt file in /etc/httpd/conf/ssl.crt/"
echo "After that you have to run make in that directory."
echo ""
echo "You better edit (and understand) /etc/httpd/conf/*.conf"
echo "to suit your needs!!!"
echo ""
echo ""
echo "For information about this RPM, please read the README.RPM"
echo "in /usr/doc/apache-mod_ssl-%{version}/"
echo ""


%preun
if [ $1 = 0 ]; then
	if [ -f /var/lock/subsys/httpd ]; then
		/etc/rc.d/init.d/httpd stop
	fi
	if [ -f /etc/rc.d/init.d/httpd ]; then
		/sbin/chkconfig --del httpd
	fi
fi


%files
%defattr(644 root root 755)
%attr(755,root,root)  %dir /etc/httpd
%attr(755,root,root)  %dir /etc/httpd/conf
%attr(755,root,root)  %dir %{contentdir}/html/

%attr( - ,root,root)  %config(noreplace) /etc/httpd/conf/ssl.crl
%attr( - ,root,root)  %config(noreplace) /etc/httpd/conf/ssl.crt
%attr( - ,root,root)  %config(noreplace) /etc/httpd/conf/ssl.csr
%attr( - ,root,root)  %config(noreplace) /etc/httpd/conf/ssl.key
%attr( - ,root,root)  %config(noreplace) /etc/httpd/conf/ssl.prm
%attr(644,root,root)  %config(noreplace) /etc/httpd/conf/httpd.conf
%attr(644,root,root)  %config /etc/httpd/conf/magic
%attr(644,root,root)  %config /etc/httpd/conf/mime.types
%attr(644,root,root)  /etc/httpd/conf/httpd.conf.default
%attr(644,root,root)  %config /etc/logrotate.d/*
%attr(755,root,root)  %config /etc/rc.d/init.d/*

%attr( - ,root,root)  %doc apache_%{apversion}/{ABOUT_APACHE}
%attr( - ,root,root)  %doc apache_%{apversion}/{LICENSE,LICENSE.SSL,README,README.SSL}
%attr( - ,root,root)  %doc apache_%{apversion}/src/{CHANGES,CHANGES.SSL,README.EAPI}
%attr( - ,root,root)  %doc apache_%{apversion}/src/support/suexec.[ch]
%attr( - ,root,root)  %doc mod_ssl-%{modversion}-%{apversion}/README.*
%attr( - ,root,root)  %doc mod_ssl-%{modversion}-%{apversion}/NEWS
%attr( - ,root,root)  %doc mod_ssl-%{modversion}-%{apversion}/contrib/
%attr(644,root,root)  %doc $RPM_SOURCE_DIR/README.RPM

%attr(755,root,root)  %dir %{contentdir}
%attr(755,root,root)  %dir %{contentdir}/cgi-bin
%attr( - ,root,root)  %{contentdir}/icons
%attr( - ,root,root)  %{contentdir}/html/*.html*
%attr( - ,root,root)  %{contentdir}/html/*.gif*

%attr( - ,root,root)  %{_libdir}/%{aname}
%attr( - ,root,root)  %{_mandir}/man1/*
%attr( - ,root,root)  %{_mandir}/man8/ab.*
%attr( - ,root,root)  %{_mandir}/man8/apachectl.*
%attr( - ,root,root)  %{_mandir}/man8/httpd.*
%attr( - ,root,root)  %{_mandir}/man8/logresolve.*
%attr( - ,root,root)  %{_mandir}/man8/rotatelogs.*
%attr( - ,root,root)  %{_mandir}/man8/suexec.*

%attr( - ,root,root)  %{_sbindir}/ab
%attr( - ,root,root)  %{_sbindir}/apachectl
%attr( - ,root,root)  %{_sbindir}/httpd
%attr( - ,root,root)  %{_sbindir}/logresolve
%attr( - ,root,root)  %{_sbindir}/rotatelogs
%attr(711,root,root)  %{_sbindir}/suexec
%attr( - ,root,root)  %{_bindir}

%attr(-,nobody,nobody) %dir %{cachedir}
%attr( - ,root,root)  %dir %{logdir}


%files devel
%defattr(644 root root 755)
%attr( - ,root,root)  %{_includedir}/%{aname}
%attr( - ,root,root)  %{_sbindir}/apxs
%attr( - ,root,root)  %{_mandir}/man8/apxs.*


%files manual
%defattr(-,root,root)
%dir %{contentdir}/manual
%{contentdir}/manual/LICENSE
%{contentdir}/manual/*.html
%{contentdir}/manual/images
%{contentdir}/manual/misc
#%{contentdir}/manual/search
%{contentdir}/manual/vhosts
%dir %{contentdir}/manual/mod
%{contentdir}/manual/mod/*.html

%changelog
* Mon Aug 19 2002 Henri Gomez <hgomez@users.sourceforge.net>
- apache 1.3.26 + mod_ssl 2.8.10
- updated to mm 1.2.1

* Thu Jun 20 2002 Henri Gomez <hgomez@users.sourceforge.net>
- apache 1.3.26 + mod_ssl 2.8.9
- security fix, upgrade to this release
- add Redhat6 layout, Redhat 7.x is now the default for ASF
- manual is in /home/httpd/manual instead of /home/httpd/html/manual
- initd script now set HAVE_SSL instead of SSL, so you should
  replace in your httpd.conf <IfDefine SSL> by <IfDefine HAVE_SSL>

* Mon Apr 08 2002 Henri Gomez <hgomez@users.sourceforge.net>
- apache 1.3.24 + mod_ssl 2.8.8

* Mon Mar 11 2002 Henri Gomez <hgomez@users.sourceforge.net>
- apache 1.3.23 + mod_ssl 2.8.7

* Mon Feb 18 2002 Henri Gomez <hgomez@users.sourceforge.net>
- apache 1.3.23 + mod_ssl 2.8.6 

* Tue Oct 23 2001 Henri Gomez <hgomez@users.sourceforge.net>
- apache 1.3.22 + mod_ssl 2.8.5 RPM 

* Mon May 21 2001 Henri Gomez <hgomez@users.sourceforge.net>
- apache 1.3.20 + mod_ssl 2.8.4 RPM release 2
- removed the RSA warning for USA (no need for a separate build in USA)
- removed manual pages from main package (live now in manual sub-package) 

* Mon May 21 2001 Henri Gomez <hgomez@users.sourceforge.net>
- apache 1.3.20 + mod_ssl 2.8.4
- built under Redhat 6.2 + updates and rpm 3.0.5
- removed glibc patch (included now in apache 1.3.20)

* Tue May 15 2001 Henri Gomez <hgomez@users.sourceforge.net>
- apache 1.3.19 + mod_ssl 2.8.3
- built under Redhat 6.2 + updates and rpm 3.0.5 
- back from rpm 4.0.2 to rpm 3.0.5 for better compatibility with previous Redhat 6.x

* Tue Apr 17 2001 Henri Gomez <hgomez@users.sourceforge.net>
- apache 1.3.19 + mod_ssl 2.8.2
- built under Redhat 6.2 + updates and rpm 4.0.2

* Mon Mar 05 2001 Henri Gomez <hgomez@users.sourceforge.net>
- apache 1.3.19 + mod_ssl 2.8.1
- remove SERIAL from spec since not used anymore
- added db1 patch in case of rebuilt under Redhat 7.x
- create a new package manual (production site didn't need it)
- added %{contentdir} (a la RH 7.0)

* Tue Jan 30 2001 Henri Gomez <hgomez@users.sourceforge.net>
- apache 1.3.17 + mod_ssl 2.8.0
- needed openssl 0.9.6
- built under Redhat 6.2 + updates

* Mon Jan 15 2001 Henri Gomez <hgomez@users.sourceforge.net>
- RPM release 2
- rebuilt against openssl 0.9.6

* Mon Oct 16 2000 Henri Gomez <hgomez@users.sourceforge.net>
- apache 1.3.14 + mod_ssl 2.7.1
- require for openssl >= 0.9.5a

* Mon Aug 29 2000 Henri Gomez <hgomez@users.sourceforge.net>
- handle compressed man files (ie: Redhat 6.2)
- update README.RPM (since no more release numbering workaround)

* Mon Aug 14 2000 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.6.6

* Thu Jul 13 2000 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.6.5
- mm 1.1.3
- removed RedHat 5.x/6.x release numbering workaround

* Wed May  5 2000 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.6.4
- mm 1.1.1

* Wed Apr 19 2000 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.6.3

* Wed Mar  8 2000 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.6.2

* Thu Mar  2 2000 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.6.1

* Mon Feb 28 2000 Magnus Stenman <stone@hkust.se>
- apache 1.3.12
- mod_ssl 2.6.0

* Mon Feb 28 2000 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.5.1

* Mon Jan 24 2000 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.5.0
- apache 1.3.11
- suexec is compiled with umask 022
- latest RedHat logrotate and init scripts included

* Wed Jan 12 2000 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.4.10

* Thu Nov 25 1999 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.4.9

* Tue Nov  2 1999 Henri Gomez <gomez@users.sourceforge.net>
- mod_ssl 2.4.7

* Fri Oct 22 1999 Henri Gomez <gomez@users.sourceforge.net>
- mod_ssl 2.4.6
- mm 1.0.12

* Tue Oct  1 1999 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.4.5
- removed semctl patch

* Tue Sep 28 1999 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.4.4
- semctl patch

* Mon Sep 27 1999 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.4.3
- mm 1.0.11
- added (noreplace) to some configuration files
- removed patch to cca.sh
- added the ssl.crl and ssl.prm subdirs in conf/

* Mon Sep  6 1999 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.4.2
- removed patch to loadcacert.cgi

* Tue Aug 31 1999 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.4.1

* Thu Aug 26 1999 Magnus Stenman <stone@hkust.se>
- added README.RPM, removed README.suexec
- added redhat-release dependencies because people
  installed 5.2 RPMs on 6.0 machines
- openssl must now be >= 0.9.4

* Fri Aug 20 1999 Magnus Stenman <stone@hkust.se>
- apache 1.3.9
- mod_ssl 2.4.0
- removed various patches to the apache source
- now using the RedHat installation path layout

* Tue Aug  3 1999 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.3.11
- removed some patches to the apache source, which
  now are performed by mod_ssl

* Thu Jul 29 1999 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.3.10

* Sun Jul 25 1999 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.3.8
- removed Thawte Strong Extranet Support due to
  apxs dependency problem
- changed release numbering to allow for
  simultaneous RedHat versions;
  release 0.5.2 means release 0, for RedHat 5.2

* Fri Jul 16 1999 Henri Gomez <gomez@users.sourceforge.net>
- mod_ssl 2.3.6
- mm 1.0.9
- removed eapimm (now in mod_ssl)

* Fri Jun 25 1999 Henri Gomez <gomez@users.sourceforge.net>
- mm 1.0.8
- added eapimm patch.

* Wed Jun 23 1999 Henri Gomez <gomez@users.sourceforge.net>
- mod_ssl 2.3.5 + mm 1.0.7
- now use MM shm instead dbm for SSLSessionCache
- stripped modules to reduce size
- add Thawte Strong Extranet Support

* Tue Jun  8 1999 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.3.2
- added the mm shared memory library

* Tue May 25 1999 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.3.1

* Tue May 25 1999 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.3.0
- Changes in URLs and description
- Included more mod_ssl documentation, and
  the mod_ssl contrib directory.
- Added require for openssl >= 0.9.3

* Mon May 17 1999 Henri Gomez <gomez@users.sourceforge.net>
- ndbm localisation patch.
  following RPM 3.x naming conventions.

* Wed Apr 21 1999 Magnus Stenman <stone@hkust.se>
- Moved header files and apxs to -devel package
  Stripped httpd binary
  Removed suid bit from suexec (see README.suexec)
  Thanks to Mike McHenry <mmchen@minn.net>
  and David Harris <dharris@drh.net>

* Mon Apr 12 1999 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.2.8

* Mon Mar 29 1999 Magnus Stenman <stone@hkust.se>
- mod_ssl 2.2.7

* Wed Mar 24 1999 Magnus Stenman <stone@hkust.se>
- New versions of apache and mod_ssl
- Added the new --enable-module=define
- Included more mod_ssl READMEs

* Fri Mar 19 1999 Magnus Stenman <stone@hkust.se>
- New version of mod_ssl

* Sun Feb 21 1999 Magnus Stenman <stone@hkust.se>
- New version of mod_ssl
- Removed SSLeay explicit require,
  libssl.so.0 and libcrypto.so.0 can be provided by any package.
  Thanks to Niels Poppe <niels@netbox.org>

* Mon Feb  5 1999 Magnus Stenman <stone@hkust.se>
- New version of mod_ssl

* Mon Feb  4 1999 Magnus Stenman <stone@hkust.se>
- New version of mod_ssl

* Mon Feb  1 1999 Henri Gomez <gomez@users.sourceforge.net>
- ServerRoot is in /home/httpd/html instead of /home/httpd/htdocs
  to follow Redhat way.
- Added provide WebServer for mod_php3.

* Thu Jan 28 1999 Magnus Stenman <stone@hkust.se>
- Fixed include files needed for apxs compiles
  Thanks to Manuel J. Galan <manolow@step.es>

* Wed Jan 27 1999 Magnus Stenman <stone@hkust.se>
- New version of mod_ssl
  Changed directory layout to be more "RedHat style"

* Wed Jan 20 1999 Magnus Stenman <stone@hkust.se>
- Initial build by Magnus, tweaked so it fits me.
  Based on the SRPM by Manuel J. Galan <manolow@step.es>
